# Code generated by highflame-policy-codegen. DO NOT EDIT.
# Source: schemas/sentry/context.json

"""Context attribute keys for Sentry Sentry browser security — monitors AI chat interactions and enforces data-protection, content-safety, and compliance policies."""

class SentryContextKey:
    """Context keys for Sentry policy evaluation."""

    CODE_LANGUAGES: str = "code_languages"
    CODE_RATIO: str = "code_ratio"
    CONTAINS_CODE: str = "contains_code"
    CONTAINS_INVISIBLE_CHARS: str = "contains_invisible_chars"
    CONTAINS_SECRETS: str = "contains_secrets"
    CONTENT: str = "content"
    CONTENT_TOPICS: str = "content_topics"
    CRIME_SCORE: str = "crime_score"
    DETECTED_LANGUAGE: str = "detected_language"
    DETECTED_SCRIPT: str = "detected_script"
    DETECTED_THREATS: str = "detected_threats"
    ENCODED_CONTENT_DETECTED: str = "encoded_content_detected"
    ENCODED_COUNT: str = "encoded_count"
    ENCODED_SCORE: str = "encoded_score"
    ENCODED_TYPES: str = "encoded_types"
    EVENT: str = "event"
    FACTUALITY_SCORE: str = "factuality_score"
    FILE_EXTENSION: str = "file_extension"
    FILE_NAME: str = "file_name"
    FILE_SIZE_BYTES: str = "file_size_bytes"
    FILE_TYPE: str = "file_type"
    HALLUCINATION_SCORE: str = "hallucination_score"
    HATE_SPEECH_SCORE: str = "hate_speech_score"
    HIGHEST_SEVERITY: str = "highest_severity"
    INJECTION_SCORE: str = "injection_score"
    INVISIBLE_CHARS_SCORE: str = "invisible_chars_score"
    IS_ENCRYPTED: str = "is_encrypted"
    IS_ENGLISH: str = "is_english"
    IS_LATIN_SCRIPT: str = "is_latin_script"
    IS_RIGHTS_MANAGED: str = "is_rights_managed"
    JAILBREAK_SCORE: str = "jailbreak_score"
    KEYWORD_CATEGORIES: str = "keyword_categories"
    KEYWORD_COUNT: str = "keyword_count"
    KEYWORD_MATCHED: str = "keyword_matched"
    LANGUAGE_CONFIDENCE: str = "language_confidence"
    MAX_THREAT_SEVERITY: str = "max_threat_severity"
    MIP_LABEL_ID: str = "mip_label_id"
    MIP_LABEL_NAME: str = "mip_label_name"
    PASTE_LENGTH: str = "paste_length"
    PASTE_SOURCE_APP: str = "paste_source_app"
    PASTE_SOURCE_URL: str = "paste_source_url"
    PHISHING_DETECTED: str = "phishing_detected"
    PII_CONFIDENCE: str = "pii_confidence"
    PII_COUNT: str = "pii_count"
    PII_DETECTED: str = "pii_detected"
    PII_TYPES: str = "pii_types"
    PROFANITY_SCORE: str = "profanity_score"
    SCRIPT_CONFIDENCE: str = "script_confidence"
    SECRET_COUNT: str = "secret_count"
    SECRET_TYPES: str = "secret_types"
    SENSITIVITY_LEVEL: str = "sensitivity_level"
    SESSION_INJECTION_DETECTED: str = "session_injection_detected"
    SESSION_PII_DETECTED: str = "session_pii_detected"
    SESSION_PII_TYPES: str = "session_pii_types"
    SESSION_SECRET_TYPES: str = "session_secret_types"
    SESSION_SECRETS_DETECTED: str = "session_secrets_detected"
    SESSION_THREAT_TURNS: str = "session_threat_turns"
    SEXUAL_SCORE: str = "sexual_score"
    SOURCE: str = "source"
    TARGET_APP: str = "target_app"
    TARGET_URL: str = "target_url"
    THREAT_CATEGORIES: str = "threat_categories"
    THREAT_COUNT: str = "threat_count"
    TOPIC_CONFIDENCE: str = "topic_confidence"
    USER_EMAIL: str = "user_email"
    VIOLENCE_SCORE: str = "violence_score"
    WEAPONS_SCORE: str = "weapons_score"
