# Code generated by highflame-policy-codegen. DO NOT EDIT.
# Source: schemas/overwatch/context.json

"""Context attribute keys for Overwatch Overwatch IDE agent security & policy enforcement."""

class OverwatchContextKey:
    """Context keys for Overwatch policy evaluation."""

    CONTAINS_INVISIBLE_CHARS: str = "contains_invisible_chars"
    CONTAINS_SECRETS: str = "contains_secrets"
    CONTENT: str = "content"
    CRIME_SCORE: str = "crime_score"
    CWD: str = "cwd"
    DETECTED_THREATS: str = "detected_threats"
    EVENT: str = "event"
    HATE_SPEECH_SCORE: str = "hate_speech_score"
    HIGHEST_SEVERITY: str = "highest_severity"
    INDIRECT_INJECTION_SCORE: str = "indirect_injection_score"
    INJECTION_CONFIDENCE: str = "injection_confidence"
    INJECTION_DEEP_CONTEXT_SCORE: str = "injection_deep_context_score"
    INJECTION_PULSE_SCORE: str = "injection_pulse_score"
    INVISIBLE_CHARS_SCORE: str = "invisible_chars_score"
    JAILBREAK_CONFIDENCE: str = "jailbreak_confidence"
    JAILBREAK_DEEP_CONTEXT_SCORE: str = "jailbreak_deep_context_score"
    JAILBREAK_PULSE_SCORE: str = "jailbreak_pulse_score"
    LOOP_COUNT: str = "loop_count"
    LOOP_DETECTED: str = "loop_detected"
    LOOP_TOOL: str = "loop_tool"
    MAX_THREAT_SEVERITY: str = "max_threat_severity"
    MCP_CONFIG_RISK: str = "mcp_config_risk"
    MCP_RISK_SCORE: str = "mcp_risk_score"
    MCP_SERVER: str = "mcp_server"
    MCP_SERVER_VERIFIED: str = "mcp_server_verified"
    MCP_TOOL: str = "mcp_tool"
    PATH: str = "path"
    PATTERN_TYPE: str = "pattern_type"
    PII_CONFIDENCE: str = "pii_confidence"
    PII_COUNT: str = "pii_count"
    PII_DETECTED: str = "pii_detected"
    PII_TYPES: str = "pii_types"
    PROFANITY_SCORE: str = "profanity_score"
    PROMPT_TEXT: str = "prompt_text"
    RESPONSE_CONTENT: str = "response_content"
    RUG_PULL_DETECTED: str = "rug_pull_detected"
    RUG_PULL_SCORE: str = "rug_pull_score"
    SECRET_COUNT: str = "secret_count"
    SECRET_TYPES: str = "secret_types"
    SEQUENCE_RISK: str = "sequence_risk"
    SESSION_COMMAND_INJECTION: str = "session_command_injection"
    SESSION_CUMULATIVE_RISK_SCORE: str = "session_cumulative_risk_score"
    SESSION_INJECTION_DETECTED: str = "session_injection_detected"
    SESSION_MAX_COMMAND_INJECTION_SCORE: str = "session_max_command_injection_score"
    SESSION_MAX_INJECTION_SCORE: str = "session_max_injection_score"
    SESSION_MAX_JAILBREAK_SCORE: str = "session_max_jailbreak_score"
    SESSION_MAX_PII_SCORE: str = "session_max_pii_score"
    SESSION_MAX_SECRET_SCORE: str = "session_max_secret_score"
    SESSION_PII_DETECTED: str = "session_pii_detected"
    SESSION_PII_TYPES: str = "session_pii_types"
    SESSION_SECRET_TYPES: str = "session_secret_types"
    SESSION_SECRETS_DETECTED: str = "session_secrets_detected"
    SESSION_THREAT_TURNS: str = "session_threat_turns"
    SEXUAL_SCORE: str = "sexual_score"
    SOURCE: str = "source"
    SUSPICIOUS_PATTERN: str = "suspicious_pattern"
    THREAT_CATEGORIES: str = "threat_categories"
    THREAT_COUNT: str = "threat_count"
    TOOL_CATEGORY: str = "tool_category"
    TOOL_IS_BUILTIN: str = "tool_is_builtin"
    TOOL_IS_SENSITIVE: str = "tool_is_sensitive"
    TOOL_NAME: str = "tool_name"
    TOOL_POISONING_DETECTED: str = "tool_poisoning_detected"
    TOOL_POISONING_SCORE: str = "tool_poisoning_score"
    TOOL_RISK_SCORE: str = "tool_risk_score"
    USER_EMAIL: str = "user_email"
    VIOLENCE_SCORE: str = "violence_score"
    WEAPONS_SCORE: str = "weapons_score"
    WORKSPACE_ROOT: str = "workspace_root"
