# Code generated by highflame-policy-codegen. DO NOT EDIT.
# Source: schemas/guardrails/context.json

"""Context attribute keys for Guardrails Guardrails (Shield) content security & policy enforcement for LLM applications."""

class GuardrailsContextKey:
    """Context keys for Guardrails policy evaluation."""

    AGENT_FRAMEWORK: str = "agent_framework"
    AGENT_ID: str = "agent_id"
    AGENT_PUBLISHER: str = "agent_publisher"
    AGENT_TRUST_LEVEL: str = "agent_trust_level"
    AGENT_TYPE: str = "agent_type"
    BUDGET_EXCEEDED: str = "budget_exceeded"
    BUDGET_REMAINING_PCT: str = "budget_remaining_pct"
    CODE_LANGUAGES: str = "code_languages"
    CODE_RATIO: str = "code_ratio"
    COMMAND_INJECTION_DETECTED: str = "command_injection_detected"
    COMMAND_INJECTION_SCORE: str = "command_injection_score"
    COMMAND_INJECTION_TYPE: str = "command_injection_type"
    CONTAINS_CODE: str = "contains_code"
    CONTAINS_INVISIBLE_CHARS: str = "contains_invisible_chars"
    CONTAINS_NON_ASCII: str = "contains_non_ascii"
    CONTAINS_SECRETS: str = "contains_secrets"
    CONTENT_SAFETY_BLOCKED: str = "content_safety_blocked"
    CONTENT_SAFETY_SCORE: str = "content_safety_score"
    CONTENT_TOPICS: str = "content_topics"
    CONTENT_TYPE: str = "content_type"
    CONVERSATION_TURN: str = "conversation_turn"
    CRIME_SCORE: str = "crime_score"
    CROSS_ORIGIN_DETECTED: str = "cross_origin_detected"
    CROSS_ORIGIN_SCORE: str = "cross_origin_score"
    CROSS_ORIGIN_TYPE: str = "cross_origin_type"
    DETECTED_LANGUAGE: str = "detected_language"
    DETECTED_SCRIPT: str = "detected_script"
    DETECTOR_COUNT: str = "detector_count"
    DIRECTION: str = "direction"
    ENCODED_CONTENT_DETECTED: str = "encoded_content_detected"
    ENCODED_COUNT: str = "encoded_count"
    ENCODED_SCORE: str = "encoded_score"
    ENCODED_TYPES: str = "encoded_types"
    FACTUALITY_SCORE: str = "factuality_score"
    HALLUCINATION_SCORE: str = "hallucination_score"
    HATE_SPEECH_SCORE: str = "hate_speech_score"
    HIGHEST_SEVERITY: str = "highest_severity"
    INDIRECT_INJECTION_SCORE: str = "indirect_injection_score"
    INDIRECT_INJECTION_TYPE: str = "indirect_injection_type"
    INJECTION_CONFIDENCE: str = "injection_confidence"
    INJECTION_DEEP_CONTEXT_SCORE: str = "injection_deep_context_score"
    INJECTION_PULSE_SCORE: str = "injection_pulse_score"
    INJECTION_TYPE: str = "injection_type"
    INVISIBLE_CHARS_SCORE: str = "invisible_chars_score"
    IS_ENGLISH: str = "is_english"
    IS_LATIN_SCRIPT: str = "is_latin_script"
    JAILBREAK_CONFIDENCE: str = "jailbreak_confidence"
    JAILBREAK_DEEP_CONTEXT_SCORE: str = "jailbreak_deep_context_score"
    JAILBREAK_PULSE_SCORE: str = "jailbreak_pulse_score"
    KEYWORD_CATEGORIES: str = "keyword_categories"
    KEYWORD_COUNT: str = "keyword_count"
    KEYWORD_MATCHED: str = "keyword_matched"
    LANGUAGE_CONFIDENCE: str = "language_confidence"
    LOOP_COUNT: str = "loop_count"
    LOOP_DETECTED: str = "loop_detected"
    LOOP_TOOL: str = "loop_tool"
    MCP_CONFIG_RISK: str = "mcp_config_risk"
    MCP_RISK_SCORE: str = "mcp_risk_score"
    MCP_RISK_TYPE: str = "mcp_risk_type"
    MCP_SERVER: str = "mcp_server"
    MCP_SERVER_VERIFIED: str = "mcp_server_verified"
    MCP_TOOL: str = "mcp_tool"
    MULTI_TURN_DETECTION: str = "multi_turn_detection"
    PATH: str = "path"
    PATH_TRAVERSAL_DETECTED: str = "path_traversal_detected"
    PATH_TRAVERSAL_SEVERITY: str = "path_traversal_severity"
    PATH_TRAVERSAL_TYPE: str = "path_traversal_type"
    PATTERN_TYPE: str = "pattern_type"
    PHISHING_DETECTED: str = "phishing_detected"
    PII_CONFIDENCE: str = "pii_confidence"
    PII_COUNT: str = "pii_count"
    PII_DETECTED: str = "pii_detected"
    PII_TYPES: str = "pii_types"
    PROFANITY_SCORE: str = "profanity_score"
    REQUEST_ID: str = "request_id"
    RUG_PULL_DETECTED: str = "rug_pull_detected"
    RUG_PULL_SCORE: str = "rug_pull_score"
    RUG_PULL_TYPE: str = "rug_pull_type"
    SCRIPT_CONFIDENCE: str = "script_confidence"
    SECRET_COUNT: str = "secret_count"
    SECRET_TYPES: str = "secret_types"
    SENTIMENT_SCORE: str = "sentiment_score"
    SEQUENCE_RISK: str = "sequence_risk"
    SESSION_COMMAND_INJECTION: str = "session_command_injection"
    SESSION_CUMULATIVE_RISK_SCORE: str = "session_cumulative_risk_score"
    SESSION_INJECTION_DETECTED: str = "session_injection_detected"
    SESSION_MAX_COMMAND_INJECTION_SCORE: str = "session_max_command_injection_score"
    SESSION_MAX_INJECTION_SCORE: str = "session_max_injection_score"
    SESSION_MAX_JAILBREAK_SCORE: str = "session_max_jailbreak_score"
    SESSION_MAX_PII_SCORE: str = "session_max_pii_score"
    SESSION_MAX_SECRET_SCORE: str = "session_max_secret_score"
    SESSION_PII_DETECTED: str = "session_pii_detected"
    SESSION_PII_TYPES: str = "session_pii_types"
    SESSION_SECRET_TYPES: str = "session_secret_types"
    SESSION_SECRETS_DETECTED: str = "session_secrets_detected"
    SESSION_THREAT_TURNS: str = "session_threat_turns"
    SEXUAL_SCORE: str = "sexual_score"
    SQL_INJECTION_DETECTED: str = "sql_injection_detected"
    SQL_INJECTION_SCORE: str = "sql_injection_score"
    SQL_INJECTION_TYPE: str = "sql_injection_type"
    SUSPICIOUS_PATTERN: str = "suspicious_pattern"
    TIMESTAMP: str = "timestamp"
    TOOL_CATEGORY: str = "tool_category"
    TOOL_IS_BUILTIN: str = "tool_is_builtin"
    TOOL_IS_SENSITIVE: str = "tool_is_sensitive"
    TOOL_NAME: str = "tool_name"
    TOOL_POISONING_DETECTED: str = "tool_poisoning_detected"
    TOOL_POISONING_SCORE: str = "tool_poisoning_score"
    TOOL_POISONING_TYPE: str = "tool_poisoning_type"
    TOOL_RISK_SCORE: str = "tool_risk_score"
    TOPIC_CONFIDENCE: str = "topic_confidence"
    VIOLENCE_SCORE: str = "violence_score"
    WEAPONS_SCORE: str = "weapons_score"
